@@ -1,12 +1,13 @@
 #!/usr/bin/perl
+# SPDX-License-Identifier: GPL-2.0-or-later
 
 use warnings;
 use strict;
 
-while (<STDIN>) {
+while (<>) {
 	chomp;
-	s/^\s*(.+)\s*$/$1/;
-	s/\s*#.*$//;
+	s/#.*$//;
+	s/^\s+//; s/\s+$//;
 	next if /^$/;
 
 	my ($fh, $fl, $lh, $ll, $s, $f, $l);
@@ -16,10 +17,10 @@ while (<STDIN>) {
 		$l = ($lh << 16) + $ll;
 
 		my $server = ($s =~ /\./) ? $s : "whois.$s.net";
-		print qq({ $f, $l,\t"$server" },\t/* $fh.$fl $lh.$ll */\n);
+		print qq|{ ${f}u, ${l}u,\t"$server" },\t/* $fh.$fl $lh.$ll */\n|;
 	} elsif (($f, $l, $s) = /^(\d+)\s+(\d+)\s+([\w\.-]+)$/) {
 		my $server = ($s =~ /\./) ? $s : "whois.$s.net";
-		print qq({ ${f}u, ${l}u,\t"$server" },\n);
+		print qq|{ ${f}u, ${l}u,\t"$server" },\n|;
 	} else {
 		die "format error: $_";
 	}
