@@ -1,12 +1,9 @@
+/* SPDX-License-Identifier: GPL-2.0-or-later */
 #include "utils.h"
 
 /* 6bone referto: extension */
 #define REFERTO_FORMAT	"%% referto: whois -h %255s -p %15s %1021[^\n\r]"
 
-/* String sent to RIPE servers - MUST NOT BE LONGER THAN FIVE CHARACTERS! */
-/* Do *NOT* change it if you don't know what you are doing! */
-#define IDSTRING "Md5.2"
-
 #define HIDE_TO_THE_END  -3
 #define HIDE_DISABLED    -2
 #define HIDE_NOT_STARTED -1
@@ -21,6 +18,7 @@ int hide_line(int *hiding, const char *const line);
 char *do_query(const int, const char *);
 char *query_crsnic(const int, const char *);
 char *query_afilias(const int, const char *);
+char *query_iana(const int, const char *);
 int openconn(const char *, const char *);
 int connect_with_timeout(int, const struct sockaddr *, socklen_t, int);
 void NORETURN usage(int error);
